@@ -24,23 +24,25 @@ impl<'a, T> ParsedItem<'a, T> {
         Some(ParsedItem(self.0, f(self.1)?))
     }
 
-    /// Map the value to a new, optional value, preserving the remaining input.
-    pub(crate) fn flat_map_res<U, V>(
-        self,
-        f: impl FnOnce(T) -> Result<U, V>,
-    ) -> Result<ParsedItem<'a, U>, V> {
-        Ok(ParsedItem(self.0, f(self.1)?))
-    }
-
-    /// Assign the stored value to the provided target. The remaining input is returned.
-    pub(crate) fn assign_value_to(self, target: &mut Option<T>) -> &'a [u8] {
-        *target = Some(self.1);
-        self.0
+    /// Consume the stored value with the provided function. The remaining input is returned.
+    #[must_use = "this returns the remaining input"]
+    pub(crate) fn consume_value(self, f: impl FnOnce(T) -> Option<()>) -> Option<&'a [u8]> {
+        f(self.1)?;
+        Some(self.0)
     }
 }
 
 impl<'a> ParsedItem<'a, ()> {
     /// Discard the unit value, returning the remaining input.
+    #[must_use = "this returns the remaining input"]
+    pub(crate) const fn into_inner(self) -> &'a [u8] {
+        self.0
+    }
+}
+
+impl<'a> ParsedItem<'a, Option<()>> {
+    /// Discard the potential unit value, returning the remaining input.
+    #[must_use = "this returns the remaining input"]
     pub(crate) const fn into_inner(self) -> &'a [u8] {
         self.0
     }
